<?php
namespace Creativeimageswap;

use Creativeimageswap\PageSettings\Page_Settings;
define( "BWDISW_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDISW_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class Classbwdiswimageswap {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdisw_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdisw_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdisw_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdisw_the_pricing_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdisw-imageswap.php' );
	}

	public function bwdisw_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\bwdiswimageSwap() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdisw-image-swap-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdisw_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdisw-image-swap-category',
			[
				'title' => esc_html__( 'Image Swap', 'bwdisw-image-swap' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdisw_all_assets_for_the_public(){
		wp_enqueue_script( 'bwdisw_image_swap_min_js', plugin_dir_url( __FILE__ ) . 'assets/public/js/min.js', array('jquery'), '1.0', true );

		$all_css_js_file = array(
            'bwdisw_image_swap_main_css' => array('bwdisw_path_define'=>BWDISW_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdisw_path_define'], null, '1.0', 'all');
        }
	}
	public function bwdisw_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdisw_author_bio_admin_icon_css' => array('bwdisw_path_admin_define'=>BWDISW_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdisw_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdisw_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdisw_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdisw_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdisw_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdisw_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
Classbwdiswimageswap::instance();